@@ -429,13 +429,12 @@
      )
 
     (parameter-declaration
-     (declaration-specifiers declarator
-			     ($$ `(param-decl ,(tl->list $1)
-					       (param-declr ,$2))))
-     (declaration-specifiers abstract-declarator
-			     ($$ `(param-decl ,(tl->list $1)
-					       (param-declr ,$2))))
-     (declaration-specifiers ($$ `(param-decl ,(tl->list $1))))
+     (declaration-specifiers
+      declarator ($$ `(param-decl ,(tl->list $1) (param-declr ,$2))))
+     (declaration-specifiers
+      abstract-declarator ($$ `(param-decl ,(tl->list $1) (param-declr ,$2))))
+     (declaration-specifiers
+      ($$ `(param-decl ,(tl->list $1))))
      )
 
     (identifier-list
@@ -609,11 +608,12 @@
      (external-declaration-list ($$ (tl->list $1)))
      )
     (external-declaration-list
-     (external-declaration ($$ (make-tl 'trans-unit $1)))
+     ;;(external-declaration ($$ (make-tl 'trans-unit $1)))
+     ($empty ($$ (make-tl 'trans-unit)))
      (external-declaration-list
       external-declaration
       ;; A ``kludge'' to deal with @code{extern "C" ...}:
-      ($$ (if (eqv? (sx-tag $2) 'extern-block) (tl-extend $1 (sx-tail $2 2))
+      ($$ (if (eqv? (sx-tag $2) 'extern-block) (tl-extend $1 (sx-tail $2 1))
 	      (tl-append $1 $2))))
      )
 
@@ -624,9 +624,10 @@
      (cpp-statement)
      (pragma)
      ("extern" $string "{" external-declaration-list "}"
-      ($$ `(extern-block ,$2 (extern-begin ,$2)
-			 ,@(sx-tail (tl->list $4) 1) (extern-end))))
-     (";" ($$ `(decl (@ (not-C99 . "GNU C")))))
+      ($$ `(extern-block (extern-begin ,$2)
+			 ,@(sx-tail (tl->list $4) 1)
+			 (extern-end))))
+     (";" ($$ `(decl (@ (extension . "GNU C")))))
      )
     
     (function-definition
@@ -643,7 +644,7 @@
      (declaration-list declaration ($$ (tl-append $1 $2)))
      )
 
-    (opt-code-comment () (code-comment))
+    (opt-code-comment ($empty) (code-comment))
 
     ;; non-terminal leaves
     (identifier
@@ -658,7 +659,7 @@
      (string-literal $string ($$ (tl-append $1 $2))))
     (code-comment ($code-comm ($$ `(comment ,$1))))
     (lone-comment ($lone-comm ($$ `(comment ,$1))))
-    (cpp-statement ('cpp-stmt))
+    (cpp-statement ('cpp-stmt ($$ `(cpp-stmt ,$1))))
     (pragma ('cpp-pragma))
     )))
 
